var path = require('path');
var assert = require('assert');
var request = require('supertest');
var app = require('../index');
var User = require('../lib/mongo').User;

var testName1 = 'testName1';
var testName2 = 'testName2';
describe('signup', function () {
  var agent = request.agent(app);//persist cookie when redirect
  describe('GET /signup', function () {
    it('signup 用 post', function (done) {
      agent.get('/signup')
        .end(function (err, res) {
          if (err)return done(err);
          assert(res.text.match(/signup请用post/));
          done();
        })
    })
  });
  describe('POST /signup', function () {
    beforeEach(function (done) {
      // 创建一个用户
      User.create({
        name: testName1,
        password: '123456',
        avatar: '',
        gender: 'x',
        bio: ''
      })
        .exec()
        .then(function () {
          done();
        })
        .catch(done);
    });

    afterEach(function (done) {
      // 删除测试用户
      User.remove({name: {$in: [testName1, testName2]}})
        .exec()
        .then(function () {
          done();
        })
        .catch(done);
    });

    //用户名错误的情况
    it('wrong name', function (done) {
      agent
        .post('/signup')
        .type('form')
        .attach('avatar', path.join(__dirname, 'avatar.png'))
        .field({name: ''})
        .end(function (err, res) {
          if (err) return done(err);
          assert.ok(res.text.match(/名字请限制在 1-10 个字符/));
          done();
        });
    });
    // 性别错误的情况
    it('wrong gender', function (done) {
      agent
        .post('/signup')
        .type('form')
        .attach('avatar', path.join(__dirname, 'avatar.png'))
        .field({name: testName2, gender: 'a'})
        .end(function (err, res) {
          if (err) return done(err);
          assert(res.text.match(/性别只能是 m、f 或 x/));
          done();
        });
    });
    // 个人简介
    it('个人简介字符限制', function (done) {
      agent
        .post('/signup')
        .type('form')
        .attach('avatar', path.join(__dirname, 'avatar.png'))
        .field({name: testName1, gender: 'm', bio: ''})
        .end(function (err, res) {
          if (err)return done(err);
          assert(res.text.match(/个人简介请限制在 1-30 个字符/));
          done();
        })
    });
    //缺少头像
    it('缺少头像', function (done) {
      agent
        .post('/signup')
        .type('form')
        .field({name: testName1, gender: 'm', bio: "简介"})
        .end(function (err, res) {
          if (err)return done(err);
          assert(res.text.match(/缺少头像/));
          done()
        })
    });
    //密码长度错误
    it('密码错误', function (done) {
      agent.post('/signup')
        .type('form')
        .attach('avatar', path.join(__dirname, 'avatar.png'))
        .field({name: testName1, gender: 'm', bio: "bio", password: "12345"})
        .end(function (err, res) {
          if (err)return done(err);
          assert(res.text.match(/密码至少 6 个字符/));
          done()
        })
    });
    //两次输入密码不一致
    it('两次输入密码不一致', function (done) {
      agent.post('/signup')
        .type('form')
        .attach('avatar', path.join(__dirname, 'avatar.png'))
        .field({name: testName1, gender: 'm', bio: "bio", password: "123456", repassword: "1234566"})
        .end(function (err, res) {
          if (err)return done(err);
          assert(res.text.match(/两次输入密码不一致/));
          done()
        })
    });
    // 用户名被占用的情况
    it('用户名被占用', function (done) {
      agent
        .post('/signup')
        .type('form')
        .attach('avatar', path.join(__dirname, 'avatar.png'))
        .field({name: testName1, gender: 'm', bio: 'noder', password: '123456', repassword: '123456'})
        .end(function (err, res) {
          if (err) return done(err);
          assert(res.text.match(/用户名已被占用/));
          done();
        });
    });

    // 注册成功的情况
    it('注册成功', function (done) {
      agent
        .post('/signup')
        .type('form')
        .attach('avatar', path.join(__dirname, 'avatar.png'))
        .field({name: testName2, gender: 'm', bio: 'noder', password: '123456', repassword: '123456'})
        .end(function (err, res) {
          if (err) return done(err);
          assert(res.text.match(/注册成功/));
          done();
        });
    });
  });
});